const system = require("../../../system");
const ServiceBase = require("../../sve.base");
var settings = require("../../../../config/settings");
const uuidv4 = require('uuid/v4');
const getRawBody = require('raw-body');
class GatewaypushlogService extends ServiceBase {
  constructor() {
    super("common", ServiceBase.getDaoName(GatewaypushlogService));
    //this.appDao=system.getObject("db.appDao");
    this.opLogUrl = settings.apiconfig.opLogUrl();
    this.opLogEsIsAdd = settings.apiconfig.opLogEsIsAdd();
  }


  getUUID() {
    var uuid = uuidv4();
    var u = uuid.replace(/\-/g, "");
    return u;
  }

  getResultSuccess(requestId) {
    return {
      "requestId": requestId,
      "success": true,
      "errorMsg": "",
      "errorCode": "ok"
    }
  }


  getResultFail(errmsg) {
    var self = this;
    return {
      "requestId": self.getUUID(),
      "success": false,
      "errorMsg": errmsg,
      "errorCode": "ok"
    };
  }


  //需求提交
  async submitNeed(pobj) {
    var self = this;
    if (!pobj.intentionBizId) {
      return self.getResultFail("intentionBizId不能为空");
    }
    if (!pobj.mobile) {
      return self.getResultFail("mobile不能为空");
    }
    if (!pobj.type) {
      return self.getResultFail("type不能为空");
    }
    var param = {
      requestId: self.getUUID(),
      requestUrl: "/api/ali/esp/intention/submit",
      requestjson: JSON.stringify(pobj),//请求地址
      pushUrl: "/action/intentionapi/queryOrderState",//调用地址
      pushActionType: "submitNeed",//调用参数
      pushtimes: 0,//推送次数
      pushStatus: "wts",//推送状态
    }
    await self.create(param);
    return self.getResultSuccess(param.requestId);
  }

  //需求关闭
  async needClose(pobj) {
    var self = this;
    if (!pobj.intentionBizId) {
      return self.getResultFail("intentionBizId不能为空");
    }
    var param = {
      requestId: self.getUUID(),
      requestUrl: "/api/ali/esp/intention/close",
      requestjson: JSON.stringify(pobj),//请求地址
      pushUrl: "/action/intentionapi/queryOrderState",//调用地址
      pushActionType: "needClose",//调用参数
      pushtimes: 0,//推送次数
      pushStatus: "wts",//推送状态
    }
    await self.create(param);
    return self.getResultSuccess(param.requestId);

  }

  //需求反馈
  async receiveFeedback(pobj) {
    var self = this;
    if (!pobj.solutionBizId) {
      return self.getResultFail("solutionBizId不能为空");
    }
    if (!pobj.operateType) {
      return self.getResultFail("operateType不能为空");
    }
    var param = {
      requestId: self.getUUID(),
      requestUrl: "/api/ali/esp/intention/solution/feedback",
      requestjson: JSON.stringify(pobj),//请求地址
      pushUrl: "/action/intentionapi/queryOrderState",//调用地址
      pushActionType: "receiveFeedback",//调用参数
      pushtimes: 0,//推送次数
      pushStatus: "wts",//推送状态
    }
    await self.create(param);
    return self.getResultSuccess(param.requestId);

  }

  //支付回调
  async paySuccess(pobj) {
    var self = this;
    if (!pobj.orderNo) {
      return { "message": "orderNo不能为空", "data": {}, "code": -200 };
    }
    if (!pobj.orderPrice) {
      if (pobj.orderPrice != 0) {
        return { "message": "orderPrice不能为空", "data": {}, "code": -200 };
      } else {
        pobj.orderPrice = "0";
      }
    }
    if (!pobj.phone) {
      return { "message": "phone不能为空", "data": {}, "code": -200 };
    }
    if (pobj.companyName) {
      if (!pobj.city) {
        return { "message": "city不能为空", "data": {}, "code": -200 };
      }
      if (!pobj.companyCategory) {
        return { "message": "companyCategory不能为空", "data": {}, "code": -200 };
      }
      if (!pobj.orgType) {
        return { "message": "orgType不能为空", "data": {}, "code": -200 };
      }
      if (!pobj.industryType) {
        return { "message": "industryType不能为空", "data": {}, "code": -200 };
      }
      if (!pobj.scope) {
        return { "message": "scope不能为空", "data": {}, "code": -200 };
      }
    } else if (pobj.park) {
      if (!pobj.productType) {
        return { "message": "productType不能为空", "data": {}, "code": -200 };
      }
    } else {
      return { "message": "参数异常", "data": {}, "code": -200 };
    }
    var param = {
      requestId: self.getUUID(),
      requestUrl: "/api/ali/ic/paySuccess",
      requestjson: JSON.stringify(pobj),//请求地址
      pushUrl: "/action/intentionapi/queryOrderState",//调用地址
      pushActionType: "paySuccess",//调用参数
      pushtimes: 0,//推送次数
      pushStatus: "wts",//推送状态
    }
    await this.create(param);
    return { "message": "true", "data": {}, "code": 200 };
  }


  //icp需求提交
  async icpSubmitNeed(pobj) {
    var self = this;
    if (!pobj.intentionBizId) {
      return self.getResultFail("intentionBizId不能为空");
    }
    if (!pobj.phone) {
      return self.getResultFail("mobile不能为空");
    }
    if (!pobj.consultType) {
      return self.getResultFail("consultType不能为空");
    }
    pobj.type = pobj.consultType;
    pobj.mobile = pobj.phone;
    var param = {
      requestId: self.getUUID(),
      requestUrl: "/api/ali/tm/consultation/submit",
      requestjson: JSON.stringify(pobj),//请求地址
      pushUrl: "/action/intentionapi/queryOrderState",//调用地址
      pushActionType: "submitNeed",//调用参数
      pushtimes: 0,//推送次数
      pushStatus: "wts",//推送状态
    }
    await self.create(param);
    return self.getResultSuccess(param.requestId);
  }

  //icp需求反馈
  async icpFeedbackSubmit(pobj) {
    var self = this;
    if (!pobj.intentionBizId) {
      return self.getResultFail("intentionBizId不能为空");
    }
    if (!pobj.description) {
      return self.getResultFail("description不能为空");
    }
    if (!pobj.intentionStatus) {
      return self.getResultFail("intentionStatus不能为空");
    }
    var param = {
      requestId: self.getUUID(),
      requestUrl: "/api/ali/tm/feedback/submit",
      requestjson: JSON.stringify(pobj),//请求地址
      pushUrl: "/action/intentionapi/queryOrderState",//调用地址
      pushActionType: "icpFeedbackSubmit",//调用参数
      pushtimes: 0,//推送次数
      pushStatus: "wts",//推送状态
    }
    await self.create(param);
    return self.getResultSuccess(param.requestId);
  }

  //icp状态变更
  async icpNotify(pobj) {
    var self = this;
    if (!pobj.bizId) {
      return self.getResultFail("bizId不能为空");
    }
    if (!pobj.status) {
      return self.getResultFail("status不能为空");
    }
    var param = {
      requestId: self.getUUID(),
      requestUrl: "/api/ali/tm/feedback/submit",
      requestjson: JSON.stringify(pobj),//请求地址
      pushUrl: "/action/intentionapi/queryOrderState",//调用地址
      pushActionType: "icpNotify",//调用参数
      pushtimes: 0,//推送次数
      pushStatus: "wts",//推送状态
    }
    await self.create(param);
    return self.getResultSuccess(param.requestId);
  }


}
module.exports = GatewaypushlogService;